pub fn probe_file(path: &Path) -> Result<StreamInfo, DecodeError>Expand description
Probe a file and return stream info without decoding.
pub fn probe_file(path: &Path) -> Result<StreamInfo, DecodeError>Probe a file and return stream info without decoding.