Module graphql_client

Module graphql_client 

Lightweight GraphQL client for connecting to a koan serve instance.

Uses blocking reqwest — call from a background thread when used from the TUI.

Structs

AlbumResult
ArtistResult
FuzzyMatch
GraphQLClient
A GraphQL client that talks to a koan server.
NowPlaying
NowPlayingTrack
QueueEntry
TrackResult

Enums

GraphQLError