cache_limit_changed

Function cache_limit_changed 

pub fn cache_limit_changed()
The cache limit was changed: work the window out again and evict down to the new limit now, rather than at the next download.