pub struct TrackBoundary {
pub id: QueueItemId,
pub path: PathBuf,
pub info: StreamInfo,
pub sample_offset: u64,
pub samples_written: u64,
pub seek_samples: u64,
}Expand description
A track boundary in the playback stream. At sample_offset cumulative
samples written to the ring buffer, this track starts.
Fields
id: QueueItemIdpath: PathBufinfo: StreamInfosample_offset: u64Cumulative interleaved samples written to the ring buffer when this track’s first sample was pushed. For the first track this is 0 (or seek_samples if seeking).
samples_written: u64Samples of this track’s audio written to ring buffer so far. Updated as decode progresses. At EOF, equals total decoded samples.
seek_samples: u64The seek offset in samples for this track (non-zero only if user seeked).