Lightweight GraphQL client for connecting to a koan serve instance.
Uses blocking reqwest — call from a background thread when used from the TUI.
Structs
- Album
Result - Artist
Result - Fuzzy
Match - GraphQL
Client - A GraphQL client that talks to a koan server.
- NowPlaying
- NowPlaying
Track - Queue
Entry - Track
Result