SubsonicClient

Struct SubsonicClient 

pub struct SubsonicClient { /* private fields */ }
Subsonic/Navidrome API client.

Implementations

Source

impl SubsonicClient

pub fn new(base_url: &str, username: &str, password: &str) -> Self

pub fn ping(&self) -> Result<(), SubsonicError>

Ping the server — verify connection and credentials.

pub fn get_artists(&self) -> Result<Vec<SubsonicArtist>, SubsonicError>

Get all artists (indexed).

pub fn get_album(&self, id: &str) -> Result<SubsonicAlbumFull, SubsonicError>

Get an album by ID, including its tracks.

pub fn get_album_list( &self, list_type: &str, size: u32, offset: u32, ) -> Result<Vec<SubsonicAlbum>, SubsonicError>

Get a paginated list of albums.

pub fn stream_url(&self, track_id: &str) -> String

Build the streaming URL for a track (doesn’t make a request).

pub fn stream_url_template(&self, track_id: &str) -> String

Stream URL without auth params — safe for database storage.

pub fn download(&self, track_id: &str, dest: &Path) -> Result<(), SubsonicError>

Download a track to a local path.

pub fn download_with_progress( &self, track_id: &str, dest: &Path, on_progress: impl Fn(u64, u64), ) -> Result<(), SubsonicError>

Download a track with progress reporting. The callback receives (bytes_downloaded, total_bytes). Total may be 0 if the server doesn’t send Content-Length.

pub fn search(&self, query: &str) -> Result<SubsonicSearchResult, SubsonicError>

Search for tracks/albums/artists.

pub fn scrobble(&self, track_id: &str) -> Result<(), SubsonicError>

Report a play (scrobble).

pub fn star(&self, track_id: &str) -> Result<(), SubsonicError>

Star (favourite) a track on the server.

pub fn unstar(&self, track_id: &str) -> Result<(), SubsonicError>

Unstar (unfavourite) a track on the server.

pub fn get_starred(&self) -> Result<Vec<SubsonicSong>, SubsonicError>

Get all starred (favourite) songs from the server.

pub fn create_share( &self, ids: &[&str], description: Option<&str>, ) -> Result<SubsonicShare, SubsonicError>

Create a sharing link for one or more resources (songs, albums, etc). Returns the created share including its ID which forms the public URL.

pub fn get_similar_songs( &self, song_id: &str, count: usize, ) -> Result<Vec<SubsonicSong>, SubsonicError>

Get similar songs for a track (Subsonic getSimilarSongs2 endpoint). Returns up to count similar songs based on the server’s algorithm.

pub fn get_top_songs( &self, artist_name: &str, count: usize, ) -> Result<Vec<SubsonicSong>, SubsonicError>

Get top songs for an artist by name.

pub fn base_url(&self) -> &str

The configured server base URL (for constructing share links etc).